==> webviz_subsurface_components-0.4.8rc1.tar.gz: webviz_subsurface_components-0.4.8rc1/react/src/lib/components/WellLogViewer/components/InfoPanel.test.tsx <==
import { render } from "@testing-library/react";
import "jest-styled-components";
import "@testing-library/jest-dom";
import React from "react";
import InfoPanel from "./InfoPanel";

describe("Test Info panel", () => {
    it("snapshot test", () => {
        const { container } = render(
            <InfoPanel
                header="Readout"
                infos={[
                    {
                        color: "black",
                        value: 2366,
                        type: "line",
                        track_id: "",
                        name: "DVER",
                        units: "M",
                    },
                    {
                        color: "",
                        value: Number.NaN,
                        type: "separator",
                        track_id: "",
                    },
                    {
                        color: "orange",
                        value: 8.5,
                        type: "line",
                        track_id: "",
                        name: "BDIA",
                        units: "INCH",
                    },
                ]}
            />
        );
        expect(container.firstChild).toMatchSnapshot();
    });
    it("snapshot test when value is infinity", () => {
        const { container } = render(
            <InfoPanel
                header="Readout"
                infos={[
                    {
                        color: "black",
                        value: Infinity,
                        type: "line",
                        track_id: "",
                        name: "DVER",
                        units: "M",
                    },
                ]}
            />
        );
        expect(container.firstChild).toMatchSnapshot();
    });
});

==> webviz_subsurface_components-0.4.15a2.tar.gz: webviz_subsurface_components-0.4.15a2/react/src/lib/components/WellLogViewer/components/InfoPanel.test.tsx <==
import { render } from "@testing-library/react";
import "jest-styled-components";
import "@testing-library/jest-dom";
import React from "react";
import InfoPanel from "./InfoPanel";

describe("Test Info panel", () => {
    it("snapshot test", () => {
        const { container } = render(
            <InfoPanel
                header="Readout"
                infos={[
                    {
                        color: "black",
                        value: 2366,
                        type: "line",
                        trackId: "",
                        name: "DVER",
                        units: "M",
                    },
                    {
                        color: "",
                        value: Number.NaN,
                        type: "separator",
                        trackId: "",
                    },
                    {
                        color: "orange",
                        value: 8.5,
                        type: "line",
                        trackId: "",
                        name: "BDIA",
                        units: "INCH",
                    },
                ]}
            />
        );
        expect(container.firstChild).toMatchSnapshot();
    });
    it("snapshot test when value is infinity", () => {
        const { container } = render(
            <InfoPanel
                header="Readout"
                infos={[
                    {
                        color: "black",
                        value: Infinity,
                        type: "line",
                        trackId: "",
                        name: "DVER",
                        units: "M",
                    },
                ]}
            />
        );
        expect(container.firstChild).toMatchSnapshot();
    });
});
